# Tutorials

Claude Knowledge Catalystの実践的なチュートリアル集です。段階別に学習し、効果的な知識管理を実現しましょう。

## Contents

```{toctree}
:maxdepth: 2
:caption: Tutorials
:hidden:

```

## チュートリアル概要

### 🌱 初級チュートリアル

#### Basic Usage（準備中）
CKCの基本的な使用方法を学びます：
- 初期セットアップ
- 基本的なファイル同期
- メタデータの自動抽出
- 簡単な知識管理

**所要時間**: 15分  
**前提知識**: なし

### 🌿 中級チュートリアル

#### Advanced Workflows（準備中）
より高度なワークフローを構築します：
- カスタムテンプレートの作成
- 自動化されたメタデータ強化
- プロジェクト横断の知識管理
- 成熟度レベルの活用

**所要時間**: 30分  
**前提知識**: Basic Usage完了

#### Obsidian Integration（準備中）
Obsidianとの深層統合を活用します：
- ボルト構造の最適化
- 双方向リンクの設定
- グラフビューの活用
- PARA methodの実装

**所要時間**: 45分  
**前提知識**: Obsidianの基本操作

### 🌳 上級チュートリアル

#### Prompt Management（準備中）
プロンプトエンジニアリングの体系的管理：
- プロンプトテンプレートの設計
- 成功率追跡と改善
- コンテキスト管理
- 再利用可能なプロンプトライブラリの構築

**所要時間**: 60分  
**前提知識**: プロンプトエンジニアリングの基礎

#### Knowledge Organization（準備中）
大規模な知識組織の管理：
- 知識成熟度の段階的管理
- 自動分類システムの調整
- 知識ギャップの特定と改善
- 組織レベルでの知識共有

**所要時間**: 90分  
**前提知識**: 全ての中級チュートリアル完了

## 学習パス

### 🎯 クイックスタートパス（1時間）
新規ユーザー向けの最短学習コース：

1. [Quick Start](../../quick-start/index.md) (5分)
2. **Basic Usage**（準備中） (15分)
3. [Getting Started](../../getting-started/index.md) (15分)
4. **Obsidian Integration** 基礎部分（準備中） (25分)

### 📚 包括学習パス（4時間）
CKCを完全にマスターしたい方向け：

1. **基礎固め** (30分)
   - Quick Start + Getting Started
   - Basic Usage

2. **実践応用** (90分)
   - Advanced Workflows
   - Obsidian Integration

3. **専門活用** (150分)
   - Prompt Management
   - Knowledge Organization

### 🔧 開発者パス（2時間）
CKCをカスタマイズ・拡張したい開発者向け：

1. **Basic Usage**（準備中） (15分)
2. [Developer Guide](../../developer-guide/index.md) (60分)
3. [API Reference](../../api-reference/index.md) (45分)

## インタラクティブ演習

各チュートリアルには以下の要素が含まれます：

### 📝 実践演習
```bash
# 例：基本的なプロジェクト設定
mkdir my-knowledge-project
cd my-knowledge-project
uv run ckc init --template=basic
```

### ✅ チェックポイント
各セクション終了時に理解度を確認できるチェックリスト。

### 🔍 トラブルシューティング
よくある問題と解決方法の提示。

### 💡 ベストプラクティス
実際の使用で役立つコツやテクニック。

## 補完リソース

### サンプルプロジェクト
```bash
# 完全なサンプルプロジェクトをダウンロード
git clone https://github.com/drillan/ckc-tutorial-samples.git
cd ckc-tutorial-samples/basic-example
```

### 動画チュートリアル
- [CKC基本操作 (YouTube)](https://youtube.com/example)
- [Obsidian統合セットアップ (YouTube)](https://youtube.com/example)
- [プロンプト管理ワークフロー (YouTube)](https://youtube.com/example)

### コミュニティ
- [Discord Server](https://discord.gg/example) - リアルタイムサポート
- [GitHub Discussions](https://github.com/drillan/claude-knowledge-catalyst/discussions) - 質問と議論
- [Reddit Community](https://reddit.com/r/example) - ユーザー事例共有

## 次のステップ

チュートリアル完了後は以下をお勧めします：

1. **実プロジェクトで実践** - 学習内容を実際のプロジェクトに適用
2. **コミュニティ参加** - 他のユーザーと知識を共有
3. **カスタマイズ探索** - あなたのワークフローに合わせてCKCをカスタマイズ
4. **貢献を検討** - プロジェクトへの貢献で知識を還元

---

**始める準備はできましたか？** 各チュートリアルは順次公開予定です！